# jupyt

Making ipynb cooler

## Requirements

- JupyterLab >= 4.0.0

## Install

To install the extension, execute:

```bash
pip install jupyt
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall jupyt
```